@@ -31,6 +31,7 @@
 
 #include "cc-background-item.h"
 #include "gdesktop-enums-types.h"
+#include "cc-background-enum-types.h"
 
 typedef struct {
         int        width;
@@ -87,9 +88,12 @@ enum {
         PROP_FLAGS,
         PROP_SIZE,
         PROP_NEEDS_DOWNLOAD,
-        PROP_MODIFIED
+        PROP_MODIFIED,
+        N_PROPS
 };
 
+static GParamSpec *props [N_PROPS];
+
 static void     cc_background_item_finalize       (GObject               *object);
 
 G_DEFINE_TYPE (CcBackgroundItem, cc_background_item, G_TYPE_OBJECT)
@@ -222,15 +226,15 @@ cc_background_item_get_frame_thumbnail (CcBackgroundItem             *item,
                 pixbuf = gnome_bg_create_frame_thumbnail (bg,
                                                           thumbs,
                                                           &monitor_layout,
-                                                          width,
-                                                          height,
+                                                          scale_factor * width,
+                                                          scale_factor * height,
                                                           frame);
         } else {
                 pixbuf = gnome_bg_create_thumbnail (bg,
                                                     thumbs,
                                                     &monitor_layout,
-                                                    width,
-                                                    height);
+                                                    scale_factor * width,
+                                                    scale_factor * height);
         }
 
         update_size (item);
@@ -350,6 +354,14 @@ cc_background_item_get_name (CcBackgroundItem *item)
 	return item->name;
 }
 
+static void
+_add_flag (CcBackgroundItem      *item,
+           CcBackgroundItemFlags  flag)
+{
+        item->flags |= flag;
+        g_object_notify_by_pspec (G_OBJECT (item), props[PROP_FLAGS]);
+}
+
 static void
 _set_uri (CcBackgroundItem *item,
 	  const char       *value)
@@ -362,6 +374,7 @@ _set_uri (CcBackgroundItem *item,
 			g_warning ("URI '%s' is invalid", value);
 		item->uri = g_strdup (value);
 	}
+        _add_flag (item, CC_BACKGROUND_ITEM_HAS_URI);
 }
 
 
@@ -377,6 +390,7 @@ _set_uri_dark (CcBackgroundItem *item,
 			g_warning ("URI '%s' is invalid", value);
 		item->uri_dark = g_strdup (value);
 	}
+        _add_flag (item, CC_BACKGROUND_ITEM_HAS_URI_DARK);
 }
 
 const char *
@@ -400,6 +414,7 @@ _set_placement (CcBackgroundItem        *item,
                 GDesktopBackgroundStyle  value)
 {
         item->placement = value;
+        _add_flag (item, CC_BACKGROUND_ITEM_HAS_PLACEMENT);
 }
 
 static void
@@ -407,6 +422,7 @@ _set_shading (CcBackgroundItem          *item,
               GDesktopBackgroundShading  value)
 {
         item->shading = value;
+        _add_flag (item, CC_BACKGROUND_ITEM_HAS_SHADING);
 }
 
 static void
@@ -415,6 +431,7 @@ _set_primary_color (CcBackgroundItem *item,
 {
         g_free (item->primary_color);
         item->primary_color = g_strdup (value);
+        _add_flag (item, CC_BACKGROUND_ITEM_HAS_PCOLOR);
 }
 
 const char *
@@ -431,6 +448,7 @@ _set_secondary_color (CcBackgroundItem *item,
 {
         g_free (item->secondary_color);
         item->secondary_color = g_strdup (value);
+        _add_flag (item, CC_BACKGROUND_ITEM_HAS_SCOLOR);
 }
 
 const char *
@@ -496,13 +514,6 @@ cc_background_item_get_source_xml (CcBackgroundItem *item)
 	return item->source_xml;
 }
 
-static void
-_set_flags (CcBackgroundItem      *item,
-            CcBackgroundItemFlags  value)
-{
-	item->flags = value;
-}
-
 CcBackgroundItemFlags
 cc_background_item_get_flags (CcBackgroundItem *item)
 {
@@ -590,9 +601,6 @@ cc_background_item_set_property (GObject      *object,
 	case PROP_SOURCE_XML:
 		_set_source_xml (self, g_value_get_string (value));
 		break;
-	case PROP_FLAGS:
-		_set_flags (self, g_value_get_flags (value));
-		break;
 	case PROP_NEEDS_DOWNLOAD:
 		_set_needs_download (self, g_value_get_boolean (value));
 		break;
@@ -688,117 +696,96 @@ cc_background_item_class_init (CcBackgroundItemClass *klass)
         object_class->constructor = cc_background_item_constructor;
         object_class->finalize = cc_background_item_finalize;
 
-        g_object_class_install_property (object_class,
-                                         PROP_NAME,
-                                         g_param_spec_string ("name",
-                                                              "name",
-                                                              "name",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_URI,
-                                         g_param_spec_string ("uri",
-                                                              "uri",
-                                                              "uri",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_URI_DARK,
-                                         g_param_spec_string ("uri-dark",
-                                                              "uri-dark",
-                                                              "uri-dark",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_PLACEMENT,
-					 g_param_spec_enum ("placement",
-							    "placement",
-							    "placement",
-							    G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE,
-							    G_DESKTOP_BACKGROUND_STYLE_SCALED,
-							    G_PARAM_READWRITE));
+        props[PROP_NAME] = g_param_spec_string ("name",
+                                                "name",
+                                                "name",
+                                                NULL,
+                                                G_PARAM_READWRITE);
 
-        g_object_class_install_property (object_class,
-                                         PROP_SHADING,
-                                         g_param_spec_enum ("shading",
-							    "shading",
-							    "shading",
-							    G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING,
-							    G_DESKTOP_BACKGROUND_SHADING_SOLID,
-							    G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_PRIMARY_COLOR,
-                                         g_param_spec_string ("primary-color",
-                                                              "primary-color",
-                                                              "primary-color",
-                                                              "#000000000000",
-                                                              G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_SECONDARY_COLOR,
-                                         g_param_spec_string ("secondary-color",
-                                                              "secondary-color",
-                                                              "secondary-color",
-                                                              "#000000000000",
-                                                              G_PARAM_READWRITE));
+        props[PROP_URI] = g_param_spec_string ("uri",
+                                               "uri",
+                                               "uri",
+                                               NULL,
+                                               G_PARAM_READWRITE);
 
-        g_object_class_install_property (object_class,
-                                         PROP_IS_DELETED,
-                                         g_param_spec_boolean ("is-deleted",
-                                                               NULL,
-                                                               NULL,
-                                                               FALSE,
-                                                               G_PARAM_READWRITE));
+        props[PROP_URI_DARK] = g_param_spec_string ("uri-dark",
+                                                    "uri-dark",
+                                                    "uri-dark",
+                                                    NULL,
+                                                    G_PARAM_READWRITE);
 
-        g_object_class_install_property (object_class,
-                                         PROP_SOURCE_URL,
-                                         g_param_spec_string ("source-url",
-                                                              "source-url",
-                                                              "source-url",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
+        props[PROP_PLACEMENT] = g_param_spec_enum ("placement",
+                                                   "placement",
+                                                   "placement",
+                                                   G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE,
+                                                   G_DESKTOP_BACKGROUND_STYLE_SCALED,
+                                                   G_PARAM_READWRITE);
 
-        g_object_class_install_property (object_class,
-                                         PROP_SOURCE_XML,
-                                         g_param_spec_string ("source-xml",
-                                                              "source-xml",
-                                                              "source-xml",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
+        props[PROP_SHADING] = g_param_spec_enum ("shading",
+                                                 "shading",
+                                                 "shading",
+                                                 G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING,
+                                                 G_DESKTOP_BACKGROUND_SHADING_SOLID,
+                                                 G_PARAM_READWRITE);
 
-	g_object_class_install_property (object_class,
-					 PROP_FLAGS,
-					 g_param_spec_flags ("flags",
-							     "flags",
-							     "flags",
-							     G_DESKTOP_TYPE_BACKGROUND_ITEM_FLAGS,
-							     0,
-							     G_PARAM_READWRITE));
+        props[PROP_PRIMARY_COLOR] = g_param_spec_string ("primary-color",
+                                                         "primary-color",
+                                                         "primary-color",
+                                                         "#000000000000",
+                                                         G_PARAM_READWRITE);
 
-        g_object_class_install_property (object_class,
-                                         PROP_SIZE,
-                                         g_param_spec_string ("size",
-                                                              "size",
-                                                              "size",
-                                                              NULL,
-                                                              G_PARAM_READABLE));
+        props[PROP_SECONDARY_COLOR] = g_param_spec_string ("secondary-color",
+                                                           "secondary-color",
+                                                           "secondary-color",
+                                                           "#000000000000",
+                                                           G_PARAM_READWRITE);
 
-        g_object_class_install_property (object_class,
-                                         PROP_NEEDS_DOWNLOAD,
-                                         g_param_spec_boolean ("needs-download",
-                                                               NULL,
-                                                               NULL,
-                                                               TRUE,
-                                                               G_PARAM_READWRITE));
+        props[PROP_IS_DELETED] = g_param_spec_boolean ("is-deleted",
+                                                       NULL,
+                                                       NULL,
+                                                       FALSE,
+                                                       G_PARAM_READWRITE);
 
-        g_object_class_install_property (object_class,
-                                         PROP_MODIFIED,
-                                         g_param_spec_uint64 ("modified",
-                                                              "modified",
-                                                              NULL,
-                                                              0,
-                                                              G_MAXUINT64,
-                                                              0,
-                                                              G_PARAM_READWRITE));
+        props[PROP_SOURCE_URL] = g_param_spec_string ("source-url",
+                                                      "source-url",
+                                                      "source-url",
+                                                      NULL,
+                                                      G_PARAM_READWRITE);
+
+        props[PROP_SOURCE_XML] = g_param_spec_string ("source-xml",
+                                                      "source-xml",
+                                                      "source-xml",
+                                                      NULL,
+                                                      G_PARAM_READWRITE);
+
+        props[PROP_FLAGS] = g_param_spec_flags ("flags",
+                                                "flags",
+                                                "flags",
+                                                CC_TYPE_BACKGROUND_ITEM_FLAGS,
+                                                0,
+                                                G_PARAM_READABLE);
+
+        props[PROP_SIZE] = g_param_spec_string ("size",
+                                                "size",
+                                                "size",
+                                                NULL,
+                                                G_PARAM_READABLE);
+
+        props[PROP_NEEDS_DOWNLOAD] = g_param_spec_boolean ("needs-download",
+                                                           NULL,
+                                                           NULL,
+                                                           TRUE,
+                                                           G_PARAM_READWRITE);
+
+        props[PROP_MODIFIED] = g_param_spec_uint64 ("modified",
+                                                    "modified",
+                                                    NULL,
+                                                    0,
+                                                    G_MAXUINT64,
+                                                    0,
+                                                    G_PARAM_READWRITE);
+
+        g_object_class_install_properties (object_class, N_PROPS, props);
 }
 
 static void
@@ -884,7 +871,7 @@ flags_to_str (CcBackgroundItemFlags flag)
 	GFlagsClass *fclass;
 	GFlagsValue *value;
 
-	fclass = G_FLAGS_CLASS (g_type_class_peek (G_DESKTOP_TYPE_BACKGROUND_ITEM_FLAGS));
+	fclass = G_FLAGS_CLASS (g_type_class_peek (CC_TYPE_BACKGROUND_ITEM_FLAGS));
 	value = g_flags_get_first_value (fclass, flag);
 
 	g_assert (value);
@@ -953,24 +940,17 @@ files_equal (const char *a,
 {
 	g_autoptr(GFile) file1 = NULL;
 	g_autoptr(GFile) file2 = NULL;
-	gboolean retval;
 
-	if (a == NULL &&
-	    b == NULL)
+	if (a == NULL && b == NULL)
 		return TRUE;
 
-	if (a == NULL ||
-	    b == NULL)
+	if (a == NULL || b == NULL)
 		return FALSE;
 
 	file1 = g_file_new_for_commandline_arg (a);
 	file2 = g_file_new_for_commandline_arg (b);
-	if (g_file_equal (file1, file2) == FALSE)
-		retval = FALSE;
-	else
-		retval = TRUE;
 
-	return retval;
+	return g_file_equal (file1, file2);
 }
 
 static gboolean
