@@ -44,14 +44,14 @@ struct _CcUaZoomPage
   AdwNavigationPage   parent_instance;
 
   AdwSwitchRow       *desktop_zoom_row;
-  GtkSpinButton      *magnify_factor_spin;
+  AdwSpinRow         *magnify_factor_spin_row;
   AdwComboRow        *magnify_view_row;
 
   AdwSwitchRow       *magnify_outside_screen_row;
   AdwComboRow        *zoom_screen_area_row;
   AdwComboRow        *zoom_follow_behaviour_row;
 
-  GtkSwitch          *crosshair_switch;
+  AdwSwitchRow       *crosshair_row;
   AdwSwitchRow       *crosshair_overlap_mouse_row;
   GtkScale           *crosshair_thickness_scale;
   GtkScale           *crosshair_length_scale;
@@ -326,14 +326,14 @@ cc_ua_zoom_page_class_init (CcUaZoomPageClass *klass)
                                                "universal-access/cc-ua-zoom-page.ui");
 
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, desktop_zoom_row);
-  gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, magnify_factor_spin);
+  gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, magnify_factor_spin_row);
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, magnify_view_row);
 
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, magnify_outside_screen_row);
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, zoom_screen_area_row);
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, zoom_follow_behaviour_row);
 
-  gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, crosshair_switch);
+  gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, crosshair_row);
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, crosshair_overlap_mouse_row);
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, crosshair_thickness_scale);
   gtk_widget_class_bind_template_child (widget_class, CcUaZoomPage, crosshair_length_scale);
@@ -365,7 +365,7 @@ cc_ua_zoom_page_init (CcUaZoomPage *self)
                    self->desktop_zoom_row, "active",
                    G_SETTINGS_BIND_DEFAULT);
   g_settings_bind (self->magnifier_settings, "mag-factor",
-                   gtk_spin_button_get_adjustment (self->magnify_factor_spin),
+                   adw_spin_row_get_adjustment (self->magnify_factor_spin_row),
                    "value", G_SETTINGS_BIND_DEFAULT);
   g_settings_bind (self->magnifier_settings, "scroll-at-edges",
                    self->magnify_outside_screen_row, "active",
@@ -373,11 +373,11 @@ cc_ua_zoom_page_init (CcUaZoomPage *self)
 
   /* Cross hairs */
   g_settings_bind (self->magnifier_settings, "show-cross-hairs",
-                   self->crosshair_switch, "active",
+                   self->crosshair_row, "active",
                    G_SETTINGS_BIND_DEFAULT);
   g_settings_bind (self->magnifier_settings, "cross-hairs-clip",
                    self->crosshair_overlap_mouse_row, "active",
-                   G_SETTINGS_BIND_INVERT_BOOLEAN);
+                   G_SETTINGS_BIND_INVERT_BOOLEAN | G_SETTINGS_BIND_NO_SENSITIVITY);
 
   g_settings_bind (self->magnifier_settings, "cross-hairs-thickness",
                    gtk_range_get_adjustment (GTK_RANGE (self->crosshair_thickness_scale)), "value",
